@@ -55,12 +55,12 @@ public:
     {
     }
 
-    bool isSVGRootInlineBox() const Q_DECL_OVERRIDE
+    bool isSVGRootInlineBox() const override
     {
         return true;
     }
 
-    void paint(RenderObject::PaintInfo &, int tx, int ty) Q_DECL_OVERRIDE;
+    void paint(RenderObject::PaintInfo &, int tx, int ty) override;
 
     virtual int placeBoxesHorizontally(int x, int &leftPosition, int &rightPosition, bool &needsWordSpacing);
     virtual void verticallyAlignBoxes(int &heightOfBlock);
@@ -70,7 +70,7 @@ public:
     // Used by SVGInlineTextBox
     const Vector<SVGTextChunk> &svgTextChunks() const;
 
-    void walkTextChunks(SVGTextChunkWalkerBase *, const SVGInlineTextBox *textBox = 0);
+    void walkTextChunks(SVGTextChunkWalkerBase *, const SVGInlineTextBox *textBox = nullptr);
 
 private:
     friend struct SVGRootInlineBoxPaintWalker;
